@@ -203,12 +203,12 @@ my $_scrub_value = sub {
 
    $pattern and defined $v and $v =~ s{ $pattern }{}gmx;
 
+   $name =~ m{ \A [\-]? \d+ \z }mx and $name = "arg[${name}]";
+
    $opts->{optional} or $opts->{allow_null} or $len = length $v
       or  throw Unspecified, [ $name ], level => 4,
                 rv => HTTP_EXPECTATION_FAILED;
 
-   $name =~ m{ \A \d+ \z }mx and $name = "arg[${name}]";
-
    $len and $len > $opts->{max_length}
       and throw 'Parameter [_1] size [_2] too big', [ $name, $len ], level => 4,
                 rv => HTTP_REQUEST_ENTITY_TOO_LARGE;
@@ -557,7 +557,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
